ProSHADE: Class Members - Variables

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - a -

- aAngle : ProSHADE_internal_data::ProSHADE_data
- addExtraSpace : ProSHADE_settings
- allDetectedCAxes : ProSHADE_settings
- allDetectedDAxes : ProSHADE_settings
- allDetectedIAxes : ProSHADE_settings
- allDetectedOAxes : ProSHADE_settings
- allDetectedTAxes : ProSHADE_settings
- axisErrTolerance : ProSHADE_settings

### - b -

- bAngle : ProSHADE_internal_data::ProSHADE_data
- blurFactor : ProSHADE_settings
- boundsExtraSpace : ProSHADE_settings
- boundsSimilarityThreshold : ProSHADE_settings

### - c -

- cAngle : ProSHADE_internal_data::ProSHADE_data
- changeMapResolution : ProSHADE_settings
- changeMapResolutionTriLinear : ProSHADE_settings
- computeEnergyLevelsDesc : ProSHADE_settings
- computeRotationFuncDesc : ProSHADE_settings
- computeTraceSigmaDesc : ProSHADE_settings
- correlationKernel : ProSHADE_settings

### - d -

- detectedSymmetry : ProSHADE_settings

### - e -

- eMatrices : ProSHADE_internal_data::ProSHADE_data
- enLevMatrixPowerWeight : ProSHADE_settings

### - f -

- fileName : ProSHADE_internal_data::ProSHADE_data
- fileType : ProSHADE_internal_data::ProSHADE_data
- firstModelOnly : ProSHADE_settings
- forceBounds : ProSHADE_settings
- forceP1 : ProSHADE_settings

### - h -

- halfMapKernel : ProSHADE_settings

### - i -

- inputFiles : ProSHADE_settings
- inputOrder : ProSHADE_internal_data::ProSHADE_data
- integOrder : ProSHADE_settings
- integrationWeight : ProSHADE_internal_data::ProSHADE_data
- internalMap : ProSHADE_internal_data::ProSHADE_data
- invertMap : ProSHADE_settings
- isEmpty : ProSHADE_internal_data::ProSHADE_data

### - m -

- mapCOMProcessChangeX : ProSHADE_internal_data::ProSHADE_data
- mapCOMProcessChangeY : ProSHADE_internal_data::ProSHADE_data
- mapCOMProcessChangeZ : ProSHADE_internal_data::ProSHADE_data
- mapMovFromsChangeX : ProSHADE_internal_data::ProSHADE_data
- mapMovFromsChangeY : ProSHADE_internal_data::ProSHADE_data
- mapMovFromsChangeZ : ProSHADE_internal_data::ProSHADE_data
- maskFileName : ProSHADE_settings
- maskingThresholdIQRs : ProSHADE_settings
- maskMap : ProSHADE_settings
- maxBandwidth : ProSHADE_settings
- maxCompBand : ProSHADE_internal_data::ProSHADE_data
- maxShellBand : ProSHADE_internal_data::ProSHADE_data
- maxSphereDists : ProSHADE_settings
- maxSymmetryFold : ProSHADE_settings
- minSymPeak : ProSHADE_settings
- moveToCOM : ProSHADE_settings

### - n -

- noIQRsFromMedianNaivePeak : ProSHADE_settings
- normaliseMap : ProSHADE_settings
- noSpheres : ProSHADE_internal_data::ProSHADE_data

### - o -

- originalMapXCom : ProSHADE_internal_data::ProSHADE_data
- originalMapYCom : ProSHADE_internal_data::ProSHADE_data
- originalMapZCom : ProSHADE_internal_data::ProSHADE_data
- originalPdbRotCenX : ProSHADE_internal_data::ProSHADE_data
- originalPdbRotCenY : ProSHADE_internal_data::ProSHADE_data
- originalPdbRotCenZ : ProSHADE_internal_data::ProSHADE_data
- originalPdbTransX : ProSHADE_internal_data::ProSHADE_data
- originalPdbTransY : ProSHADE_internal_data::ProSHADE_data
- originalPdbTransZ : ProSHADE_internal_data::ProSHADE_data
- outName : ProSHADE_settings
- overlayStructureName : ProSHADE_settings

### - p -

- pdbBFactorNewVal : ProSHADE_settings
- peakNeighbours : ProSHADE_settings
- progressiveSphereMapping : ProSHADE_settings

### - r -

- reBoxMap : ProSHADE_settings
- recommendedSymmetryFold : ProSHADE_settings
- recommendedSymmetryType : ProSHADE_settings
- removeWaters : ProSHADE_settings
- requestedResolution : ProSHADE_settings
- requestedSymmetryFold : ProSHADE_settings
- requestedSymmetryType : ProSHADE_settings
- rotationUncertainty : ProSHADE_settings
- rotSphericalHarmonics : ProSHADE_internal_data::ProSHADE_data
- rotTrsJSONFile : ProSHADE_settings
- rrpMatrices : ProSHADE_internal_data::ProSHADE_data

### - s -

- saveMask : ProSHADE_settings
- smoothingFactor : ProSHADE_settings
- so3Coeffs : ProSHADE_internal_data::ProSHADE_data
- so3CoeffsInverse : ProSHADE_internal_data::ProSHADE_data
- spherePos : ProSHADE_internal_data::ProSHADE_data
- spheres : ProSHADE_internal_data::ProSHADE_data
- sphericalHarmonics : ProSHADE_internal_data::ProSHADE_data
- symMissPeakThres : ProSHADE_settings

### - t -

- task : ProSHADE_settings
- taylorSeriesCap : ProSHADE_settings
- translationMap : ProSHADE_internal_data::ProSHADE_data

### - u -

- useBiCubicInterpolationOnPeaks : ProSHADE_settings
- useCorrelationMasking : ProSHADE_settings
- usePeakSearchInRotationFunctionSpace : ProSHADE_settings
- usePhase : ProSHADE_settings
- useSameBounds : ProSHADE_settings

### - v -

- verbose : ProSHADE_settings

### - w -

- wignerMatrices : ProSHADE_internal_data::ProSHADE_data

### - x -

- xAxisOrder : ProSHADE_internal_data::ProSHADE_data
- xAxisOrigin : ProSHADE_internal_data::ProSHADE_data
- xAxisOriginOriginal : ProSHADE_internal_data::ProSHADE_data
- xCom : ProSHADE_internal_data::ProSHADE_data
- xDimIndices : ProSHADE_internal_data::ProSHADE_data
- xDimIndicesOriginal : ProSHADE_internal_data::ProSHADE_data
- xDimSize : ProSHADE_internal_data::ProSHADE_data
- xDimSizeOriginal : ProSHADE_internal_data::ProSHADE_data
- xFrom : ProSHADE_internal_data::ProSHADE_data
- xGridIndices : ProSHADE_internal_data::ProSHADE_data
- xTo : ProSHADE_internal_data::ProSHADE_data

### - y -

- yAxisOrder : ProSHADE_internal_data::ProSHADE_data
- yAxisOrigin : ProSHADE_internal_data::ProSHADE_data
- yAxisOriginOriginal : ProSHADE_internal_data::ProSHADE_data
- yCom : ProSHADE_internal_data::ProSHADE_data
- yDimIndices : ProSHADE_internal_data::ProSHADE_data
- yDimIndicesOriginal : ProSHADE_internal_data::ProSHADE_data
- yDimSize : ProSHADE_internal_data::ProSHADE_data
- yDimSizeOriginal : ProSHADE_internal_data::ProSHADE_data
- yFrom : ProSHADE_internal_data::ProSHADE_data
- yGridIndices : ProSHADE_internal_data::ProSHADE_data
- yTo : ProSHADE_internal_data::ProSHADE_data

### - z -

- zAxisOrder : ProSHADE_internal_data::ProSHADE_data
- zAxisOrigin : ProSHADE_internal_data::ProSHADE_data
- zAxisOriginOriginal : ProSHADE_internal_data::ProSHADE_data
- zCom : ProSHADE_internal_data::ProSHADE_data
- zDimIndices : ProSHADE_internal_data::ProSHADE_data
- zDimIndicesOriginal : ProSHADE_internal_data::ProSHADE_data
- zDimSize : ProSHADE_internal_data::ProSHADE_data
- zDimSizeOriginal : ProSHADE_internal_data::ProSHADE_data
- zFrom : ProSHADE_internal_data::ProSHADE_data
- zGridIndices : ProSHADE_internal_data::ProSHADE_data
- zTo : ProSHADE_internal_data::ProSHADE_data